@@ -12,12 +12,13 @@ from tonclient.types import Abi, Signer, CallSet, DeploySet, DebotAction, \
     DebotState, AppRequestResult, ParamsOfAppDebotBrowser, \
     ResultOfAppDebotBrowser, ParamsOfEncodeMessage, ParamsOfProcessMessage, \
     ParamsOfStart, ParamsOfFetch, ParamsOfExecute, ParamsOfAppRequest, \
-    ParamsOfResolveAppRequest, KeyPair
+    ParamsOfResolveAppRequest, KeyPair, ParamsOfQueryCollection
 
 
 class TestTonDebotAsyncCore(unittest.TestCase):
     def setUp(self) -> None:
-        self.keypair = async_custom_client.crypto.generate_random_sign_keys()
+        self.keypair = KeyPair.load(
+            path=os.path.join(SAMPLES_DIR, 'keys_raw.json'), is_binary=False)
         self.target_abi = Abi.from_path(
             path=os.path.join(SAMPLES_DIR, 'DebotTarget.abi.json'))
         self.debot_abi = Abi.from_path(
@@ -27,7 +28,8 @@ class TestTonDebotAsyncCore(unittest.TestCase):
         with open(os.path.join(SAMPLES_DIR, 'Debot.tvc'), 'rb') as fp:
             self.debot_tvc = base64.b64encode(fp.read()).decode()
 
-        self.debot_address, self.target_address = self.__deploy()
+        self.debot_address, self.target_address = self.__deploy(
+            keypair=self.keypair)
 
     def test_goto(self):
         steps = [
@@ -66,6 +68,9 @@ class TestTonDebotAsyncCore(unittest.TestCase):
             steps=steps, params=params, start_fn='start', keypair=self.keypair)
 
     def test_run_method(self):
+        keypair = async_custom_client.crypto.generate_random_sign_keys()
+        debot_address, _ = self.__deploy(keypair=keypair)
+
         steps = [
             {'choice': 3, 'inputs': [], 'outputs': ['Test Run Method Action']},
             {'choice': 0, 'inputs': [], 'outputs': []},
@@ -73,9 +78,9 @@ class TestTonDebotAsyncCore(unittest.TestCase):
             {'choice': 2, 'inputs': [], 'outputs': ['Debot Tests']},
             {'choice': 7, 'inputs': [], 'outputs': []}
         ]
-        params = ParamsOfStart(address=self.debot_address)
+        params = ParamsOfStart(address=debot_address)
         debot_browser(
-            steps=steps, params=params, start_fn='start', keypair=self.keypair)
+            steps=steps, params=params, start_fn='start', keypair=keypair)
 
     def test_send_message(self):
         steps = [
@@ -128,9 +133,9 @@ class TestTonDebotAsyncCore(unittest.TestCase):
         for action in state['actions']:
             logging.info(f'[ACTION]\t{action}')
 
-    def __deploy(self) -> Tuple[str, str]:
+    def __deploy(self, keypair: KeyPair) -> Tuple[str, str]:
         """ Deploy debot and target """
-        signer = Signer.Keys(keys=self.keypair)
+        signer = Signer.Keys(keys=keypair)
 
         # Deploy target
         call_set = CallSet(function_name='constructor')
@@ -139,34 +144,51 @@ class TestTonDebotAsyncCore(unittest.TestCase):
             abi=self.target_abi, signer=signer, deploy_set=deploy_set,
             call_set=call_set)
         message = async_custom_client.abi.encode_message(params=encode_params)
-        send_grams(address=message.address)
-        process_params = ParamsOfProcessMessage(
-            message_encode_params=encode_params, send_events=False)
-        target = async_custom_client.processing.process_message(
-            params=process_params)
+
+        # Check if target contract does not exists
+        q_params = ParamsOfQueryCollection(
+            collection='accounts', result='id',
+            filter={'id': {'eq': message.address}})
+        result = async_custom_client.net.query_collection(params=q_params)
+        if len(result.result):
+            target_address = result.result[0]['id']
+        else:
+            send_grams(address=message.address)
+            process_params = ParamsOfProcessMessage(
+                message_encode_params=encode_params, send_events=False)
+            target = async_custom_client.processing.process_message(
+                params=process_params)
+            target_address = target.transaction['account_addr']
 
         # Deploy debot
         call_set = CallSet(
             function_name='constructor', input={
                 'debotAbi': self.debot_abi.value.encode().hex(),
                 'targetAbi': self.target_abi.value.encode().hex(),
-                'targetAddr': target.transaction['account_addr']
+                'targetAddr': target_address
             })
         deploy_set = DeploySet(tvc=self.debot_tvc)
         encode_params = ParamsOfEncodeMessage(
             abi=self.debot_abi, signer=signer, deploy_set=deploy_set,
             call_set=call_set)
         message = async_custom_client.abi.encode_message(params=encode_params)
-        send_grams(address=message.address)
-        process_params = ParamsOfProcessMessage(
-            message_encode_params=encode_params, send_events=False)
-        debot = async_custom_client.processing.process_message(
-            params=process_params)
 
-        return (
-            debot.transaction['account_addr'],
-            target.transaction['account_addr']
-        )
+        # Check if debot contract does not exists
+        q_params = ParamsOfQueryCollection(
+            collection='accounts', result='id',
+            filter={'id': {'eq': message.address}})
+        result = async_custom_client.net.query_collection(params=q_params)
+        if len(result.result):
+            debot_address = result.result[0]['id']
+        else:
+            send_grams(address=message.address)
+            process_params = ParamsOfProcessMessage(
+                message_encode_params=encode_params, send_events=False)
+            debot = async_custom_client.processing.process_message(
+                params=process_params)
+            debot_address = debot.transaction['account_addr']
+
+        return debot_address, target_address
 
 
 def debot_browser(
